==> haskell-http-conduit-2.3.9.1-152-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
key:                  http-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  5dbf53235f5fcda72bcd170d27acf94f
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW
    attoparsec-aeson-2.1.0.0-DdR79qVZCk28xrg7JfXfeG base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1 mtl-2.2.2
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.9.1-181-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
key:                  http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  c92b7ea1ecf12c8e4f124cbee5d0b71d
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y
    attoparsec-aeson-2.1.0.0-BaIGvxJAWCx43bSANq38ez base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii mtl-2.2.2
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
